==> copyq_6.4.0.orig.tar.gz: CopyQ-6.4.0/src/scriptable/scriptablebytearray.h <==
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef SCRIPTABLEBYTEARRAY_H
#define SCRIPTABLEBYTEARRAY_H

#include <QByteArray>
#include <QJSValue>
#include <QObject>

class ScriptableByteArray final : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QJSValue length READ length WRITE setLength)

public:
    Q_INVOKABLE ScriptableByteArray() {}
    Q_INVOKABLE explicit ScriptableByteArray(const QByteArray &bytes);
    Q_INVOKABLE explicit ScriptableByteArray(const QString &text);
    Q_INVOKABLE explicit ScriptableByteArray(int size);

    Q_INVOKABLE ScriptableByteArray(const ScriptableByteArray &other);

    const QByteArray *data() const { return &m_self; }

public slots:
    void chop(int n);
    bool equals(const QJSValue &other);
    QJSValue left(int len) const;
    QJSValue mid(int pos, int len = -1) const;
    QJSValue remove(int pos, int len);
    QJSValue right(int len) const;
    QJSValue simplified() const;
    QJSValue toBase64() const;
    QJSValue toLower() const;
    QJSValue toUpper() const;
    QJSValue trimmed() const;
    void truncate(int pos);
    QJSValue valueOf() const;

    int size() const;

    QString toString() const;
    QString toLatin1String() const;

    QJSValue length() const;
    void setLength(QJSValue size);

private:
    QJSEngine *engine() const;

    QJSValue newByteArray(const QByteArray &bytes) const;

    QByteArray m_self;
};

const QByteArray *getByteArray(const QJSValue &value);

QByteArray toByteArray(const QJSValue &value);

QString toString(const QJSValue &value);

#endif // SCRIPTABLEBYTEARRAY_H

==> copyq_10.0.0.orig.tar.gz: CopyQ-10.0.0/src/scriptable/scriptablebytearray.h <==
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef SCRIPTABLEBYTEARRAY_H
#define SCRIPTABLEBYTEARRAY_H

#include <QByteArray>
#include <QJSValue>
#include <QObject>
#include <QVariant>

class ScriptableByteArray final : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QJSValue length READ length WRITE setLength)

public:
    Q_INVOKABLE ScriptableByteArray() {}
    Q_INVOKABLE explicit ScriptableByteArray(const QByteArray &bytes);
    Q_INVOKABLE explicit ScriptableByteArray(const QString &text);
    Q_INVOKABLE explicit ScriptableByteArray(const QVariant &value);
    Q_INVOKABLE explicit ScriptableByteArray(int size);

    Q_INVOKABLE ScriptableByteArray(const ScriptableByteArray &other);

    const QByteArray *data() { return &self(); }

public slots:
    void chop(int n);
    bool equals(const QJSValue &other);
    QJSValue left(int len);
    QJSValue mid(int pos, int len = -1);
    QJSValue remove(int pos, int len);
    QJSValue right(int len);
    QJSValue simplified();
    QJSValue toBase64();
    QJSValue toLower();
    QJSValue toUpper();
    QJSValue trimmed();
    void truncate(int pos);
    QJSValue valueOf();

    int size();

    QString toString();
    QString toLatin1String();

    QJSValue length();
    void setLength(QJSValue size);

private:
    QJSEngine *engine() const;

    QJSValue newByteArray(const QByteArray &bytes) const;

    QByteArray &self();

    QByteArray m_self;
    QVariant m_variant;
};

const QByteArray *getByteArray(const QJSValue &value);

QByteArray toByteArray(const QJSValue &value);

QString toString(const QJSValue &value);

#endif // SCRIPTABLEBYTEARRAY_H
